<!DOCTYPE html>
<html>
  <head>
    <title>The install worked successfully! Congratulations!</title>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, init-scale=1">
    <style>
      html {
        line-height: 1.15;
      }

      body {
        font-family: Roboto, sans-serif;
        margin: 0 auto;
        max-width: 960px;
      }

      header {
        padding-bottom: 10px;
        padding-top: 20px;
      }
      header .logo {
        font-size: 1.375rem;
        font-weight: 700;
        text-decoration: none;
      }

      main {
        text-align: center;
      }
      main h1 {
        font-size: 1.375rem;
        font-weight: 400;
        margin: 5px auto 0;
        max-width: 32rem;
      }
      main p {
        line-height: 1.25;
        max-width: 26rem;
        margin: 15px auto 0;
      }
    </style>
  </head>

  <body>
    <header>
      <a class="logo" href="https://huscy.org" target="_blank" rel="noopener">
        huscy
      </a>
    </header>

    <main>
      <h1>The install worked successfully! Congratulation!</h1>
      <p>You are seeing this page because you need to replace the template file <code>index.html</code> in the <code>templates/</code> directory to use your own frontend.</p>
    </main>
  </body>
</html>
